@@ -1,4 +1,4 @@
 from __future__ import absolute_import
 
 # import apis into api package
-from .persistence_api import PersistenceApi
+from .persist_api import PersistApi
